#Leb-2 analysis script 

require(tidyverse)
require(ggplot2)
require(scales)
require(viridis)
require(ggrepel)
require(scales)
require(ggpubr)

#Set wd
setwd("YOUR DIR - SET TO LEVEL OF README FILE")


#Write function to read data in and iterate over file locs 
threshold = 100000
arguments = c("R1", "R2", "R3", "R4", "R5")

f_reader <- function(arg, row_val = 2){
  file = read_tsv(paste0("./data/P3E45_", arg, ".txt"), skip = 9) %>% 
    filter(Row == as.numeric(row_val) & Column <= 3 & Column >= 2) %>%
    mutate(condition = str_replace_all(Column ,c("2" = "Vehicle", "3" = "Leb2")),
           rep = as.character(arg)) %>%
    select(condition,
           rep, 
           organoid = "Object No",
           Volume = "Touching Objects Removed - Volume Organoids Volume [m]",
           SArea = "Touching Objects Removed - Volume Organoids Surface Area [m]",
           InnerSphere = "Touching Objects Removed - Volume Organoids Maximum Inner Disk Radius [m]") %>%
    filter(Volume >= threshold)
  return(file)
}

f_num_cal <- function(tbl){
  x = NROW(tbl)
  y = median(tbl$Volume)
  z = mean(tbl$InnerSphere)
  res = data.frame("number_org" = x, "mean_vol" = y, "mean_dia" = z)
  return(res)
}

f_fc_cal <- function(tbl){
  x = (tbl %>% filter(condition == "Leb2"))$number_org/(tbl %>% filter(condition == "Vehicle"))$number_org
  res = data.frame("fc_VbL" = x)
  return(res)
}

f_global_mean_cal <- function(tbl){
  x = mean(tbl$number_org)
  y = median(tbl$mean_vol)
  sd = sd(tbl$number_org)
  sd_vol = sd(tbl$mean_vol)
  se = sd/sqrt(NROW(tbl))
  se_vol = sd_vol/sqrt(NROW(tbl))
  res = data.frame("number_org" = x, "mean_vol" = y, "global_sd_number" = sd, "global_se_number" = se, "global_sd_vol" = sd_vol, "global_se_vol" = se_vol)
  return(res)
}

f_global_fc_cal <- function(tbl){
  x = mean(tbl$fc_VbL)
  sd = sd(tbl$fc_VbL)
  se = sd/sqrt(NROW(tbl))
  res = data.frame("fc_VbL" = x, "fc_sd_VbL" = sd, "fc_se_VbL" = se)
}

leb_R1 <- f_reader(arg = "R1", row_val = 3)
leb_R2 <- f_reader(arg = "R2")
leb_R3 <- f_reader(arg = "R3")
leb_R4 <- f_reader(arg = "R4")
leb_R5 <- f_reader(arg = "R5")

full_leb_data <- rbind(leb_R1, leb_R2, leb_R3, leb_R4, leb_R5) %>%
  group_by(rep, condition) %>%
  nest() %>%
  ungroup() %>%
  mutate(data2 = map(.x = data, .f=f_num_cal)) %>%
  unnest(cols = c(data2)) %>%
  group_by(rep) %>%
  nest() %>%
  ungroup() %>%
  mutate(data2 = map(.x = data, .f = f_fc_cal)) %>% 
  unnest(cols = c(data2)) %>%
  unnest(cols = c(data)) %>%
  mutate(fc_VbL = ifelse(condition == "Vehicle", 1, fc_VbL))

full_leb_mean <- full_leb_data %>%
  select(-data) %>%
  group_by(condition) %>%
  nest() %>%
  ungroup() %>%
  mutate(data2 = map(.x = data, .f = f_global_mean_cal)) %>%
  select(-data) %>%
  unnest(cols = c(data2)) 

#Factor the data
full_leb_data$condition <- factor(full_leb_data$condition, levels = c("Vehicle", "Leb2"))
full_leb_mean$condition <- factor(full_leb_mean$condition, levels = c("Vehicle", "Leb2"))

comp = list(c("Vehicle", "Leb2"))

#Plot of the number as bar 
out_1_number <- ggplot(full_leb_data, aes(x = condition, y = number_org, group = condition, fill = condition)) + 
  geom_bar(data = full_leb_mean, aes(x = condition, y = number_org), stat = "identity", colour = "black", alpha = 0.75)+
  geom_errorbar(data = full_leb_mean, aes(ymin = number_org - global_se_number, ymax = number_org + global_se_number), width = 0.25)+
  geom_jitter(shape = 21, size = 3)+
  scale_fill_manual(values = c("#55A0FB","#F94040"))+
  scale_y_continuous(breaks = c(0, 250, 500, 750, 1000, 1250))+
  stat_compare_means(method = "t.test", comparisons = comp, label = "p.format", paired = T)+
  theme_classic()+
  theme(aspect.ratio = 3)

ggsave("./output/SF15_Number_comp.pdf", out_1_number, device = "pdf", width = 5, height = 5, unit = "in")

#Plot of the size as bar 
out_2_size <- ggplot(full_leb_data, aes(x = condition, y = mean_vol, group = condition, fill = condition)) + 
  geom_bar(data = full_leb_mean, aes(x = condition, y = mean_vol), stat = "identity", colour = "black", alpha = 0.75)+
  geom_errorbar(data = full_leb_mean, aes(ymin = mean_vol - global_se_vol, ymax = mean_vol + global_se_vol), width = 0.25)+
  geom_jitter(shape = 21, size = 3)+
  scale_fill_manual(values = c("#55A0FB","#F94040"))+
  stat_compare_means(method = "t.test", comparisons = comp, label = "p.format", paired = T)+
  theme_classic()+
  theme(aspect.ratio = 3)


ggsave("./output/SF15_size_comp.pdf", out_2_size, device = "pdf", width = 5, height = 5, unit = "in")



out_3_paired_number <- ggplot(full_leb_data, aes(x = condition, y = number_org, fill = condition)) + 
  geom_bar(data = full_leb_mean, aes(x = condition, y = number_org, group = condition), stat = "identity", fill = NA, size = 2, colour = c("#55A0FB","#F94040"), alpha = 0.75)+
  geom_line(aes(group = rep))+
  geom_point(shape = 21, size = 3)+
  scale_fill_manual(values = c("#55A0FB","#F94040"))+
  scale_y_continuous(breaks = c(0, 250, 500, 750, 1000, 1250))+
  stat_compare_means(method = "t.test", comparisons = comp, label = "p.format", paired = T)+
  theme_classic()+
  theme(aspect.ratio = 3)

ggsave("./output/F2i_number_paired.pdf", out_3_paired_number, device = "pdf", width = 5, height = 5, unit = "in")


out_4_paired_volume <- ggplot(full_leb_data, aes(x = condition, y = mean_vol, fill = condition)) + 
  geom_bar(data = full_leb_mean, aes(x = condition, y = mean_vol, group = condition), stat = "identity", fill = NA, size = 2, colour = c("#55A0FB","#F94040"), alpha = 0.75)+
  geom_line(aes(group = rep))+
  geom_point(shape = 21, size = 3)+
  scale_fill_manual(values = c("#55A0FB","#F94040"))+
  #scale_y_continuous(breaks = c(0, 250, 500, 750, 1000, 1250))+
  stat_compare_means(method = "t.test", comparisons = comp, label = "p.format", paired = T)+
  theme_classic()+
  theme(aspect.ratio = 3)

ggsave("./output/SF15_volume_paired.pdf", out_4_paired_volume, device = "pdf", width = 5, height = 5, unit = "in")

#Generate global fc for leb2 data 
full_leb_fc <- full_leb_data %>%
  group_by(condition) %>%
  nest() %>%
  ungroup() %>%
  mutate(data2 = map(.x = data, .f = f_global_fc_cal)) %>%
  select(-data) %>%
  unnest(cols = c(data2))
  
#Get fold change plot 
out_5_fc_plot <- ggplot(full_leb_data, aes(x = condition, y = fc_VbL, group = condition, fill = condition)) + 
  geom_bar(data = full_leb_fc, aes(y = fc_VbL, x = condition), stat = "identity", colour = "black")+
  geom_errorbar(data = full_leb_fc, aes(ymin = fc_VbL - fc_se_VbL, ymax = fc_VbL + fc_se_VbL), width = 0.25)+
  geom_jitter(shape = 21, size = 3)+
  scale_fill_manual(values = c("#55A0FB","#F94040"))+
  theme_classic()+
  ylim(0, 1.05)+
  theme(aspect.ratio = 3)

ggsave("./output/SF15_fc_plot.pdf", out_5_fc_plot, device = "pdf", width = 5, height = 5, unit = "in")

#Extract full data 
full_leb_data_individual <- full_leb_data %>%
  unnest(cols = c(data)) %>%
  mutate(log10_vol = log10(Volume),
         log2_is = log2(InnerSphere))

#Save individual data 
write.csv(full_leb_data_individual, "./output/SF15_Individual_vol.csv")

